@@ -537,7 +537,8 @@ static PyObject *t_timezone_setDefault(PyTypeObject *type, PyObject *arg)
 
         PyObject *m = PyImport_ImportModule("icu");
         PyObject *cls = PyObject_GetAttrString(m, "ICUtzinfo");
-        PyObject *result = PyObject_CallMethod(cls, "_resetDefault", "", NULL);
+        PyObject *result = PyObject_CallMethod(
+            cls, (char *) "_resetDefault", (char *) "", NULL);
 
         Py_DECREF(m);
         Py_DECREF(cls);
@@ -1482,10 +1483,10 @@ static PyObject *t_gregoriancalendar_isLeapYear(t_gregoriancalendar *self, PyObj
 
 void _init_calendar(PyObject *m)
 {
-    TimeZoneType.tp_str = (reprfunc) t_timezone_str;
-    TimeZoneType.tp_richcompare = (richcmpfunc) t_timezone_richcmp;
-    CalendarType.tp_str = (reprfunc) t_calendar_str;
-    CalendarType.tp_richcompare = (richcmpfunc) t_calendar_richcmp;
+    TimeZoneType_.tp_str = (reprfunc) t_timezone_str;
+    TimeZoneType_.tp_richcompare = (richcmpfunc) t_timezone_richcmp;
+    CalendarType_.tp_str = (reprfunc) t_calendar_str;
+    CalendarType_.tp_richcompare = (richcmpfunc) t_calendar_richcmp;
 
     INSTALL_CONSTANTS_TYPE(UCalendarDateFields, m);
     INSTALL_CONSTANTS_TYPE(UCalendarDaysOfWeek, m);
