@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2005-2010 Open Source Applications Foundation.
+ * Copyright (c) 2005-2015 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -133,6 +133,9 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/search.h>
 #include <unicode/stsearch.h>
 #include <unicode/uscript.h>
+#include <unicode/uchar.h>
+#include <unicode/uversion.h>
+#include <unicode/ushape.h>
 
 #define VERSION_HEX(major, minor, patch) \
   (((major) << 24) | ((minor) << 16) | ((patch) << 8))
@@ -152,6 +155,7 @@ typedef intintobjargproc ssizessizeobjargproc;
 #if U_ICU_VERSION_HEX >= 0x04020000
 #include <unicode/tmutfmt.h>
 #include <unicode/currpinf.h>
+#include <unicode/uspoof.h>
 #endif
 
 #if U_ICU_VERSION_HEX >= 0x04040000
@@ -167,6 +171,16 @@ typedef intintobjargproc ssizessizeobjargproc;
 #include <unicode/listformatter.h>
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+#include <unicode/compactdecimalformat.h>
+#include <unicode/unum.h>
+#include <unicode/udisplaycontext.h>
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+#include <unicode/reldatefmt.h>
+#endif
+
 #if U_ICU_VERSION_HEX < 0x04060000
 
 typedef UClassID classid;
@@ -311,7 +325,7 @@ public:
     }
 };
 
-#ifdef _MSC_VER
+#if defined(_MSC_VER) || defined(PYPY_VERSION)
 
 #define parseArgs __parseArgs
 #define parseArg __parseArg
@@ -319,7 +333,11 @@ public:
 int __parseArgs(PyObject *args, const char *types, ...);
 int __parseArg(PyObject *arg, const char *types, ...);
 
+#ifdef PYPY_VERSION
+int _parseArgs(PyObject *args, int count, const char *types, va_list list);
+#else
 int _parseArgs(PyObject **args, int count, const char *types, va_list list);
+#endif
 
 #else
 
