@@ -1,5 +1,5 @@
 /* ====================================================================
- * Copyright (c) 2004-2011 Open Source Applications Foundation.
+ * Copyright (c) 2004-2015 Open Source Applications Foundation.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,6 +32,19 @@
 #include "dateformat.h"
 #include "macros.h"
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+DECLARE_CONSTANTS_TYPE(UDateRelativeDateTimeFormatterStyle);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+DECLARE_CONSTANTS_TYPE(UDisplayContext);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+DECLARE_CONSTANTS_TYPE(UDateDirection);
+DECLARE_CONSTANTS_TYPE(UDateAbsoluteUnit);
+DECLARE_CONSTANTS_TYPE(UDateRelativeUnit);
+#endif
 
 /* DateFormatSymbols */
 
@@ -265,6 +278,42 @@ DECLARE_TYPE(DateIntervalFormat, t_dateintervalformat, Format,
 
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+
+/* RelativeDateTimeFormatter */
+
+class t_relativedatetimeformatter : public _wrapper {
+public:
+    RelativeDateTimeFormatter *object;
+};
+
+static int t_relativedatetimeformatter_init(t_relativedatetimeformatter *self,
+                                            PyObject *args, PyObject *kwds);
+static PyObject *t_relativedatetimeformatter_format(
+    t_relativedatetimeformatter *self, PyObject *args);
+static PyObject *t_relativedatetimeformatter_combineDateAndTime(
+    t_relativedatetimeformatter *self, PyObject *args);
+static PyObject *t_relativedatetimeformatter_getNumberFormat(
+    t_relativedatetimeformatter *self);
+static PyObject *t_relativedatetimeformatter_getCapitalizationContext(
+    t_relativedatetimeformatter *self);
+static PyObject *t_relativedatetimeformatter_getFormatStyle(
+    t_relativedatetimeformatter *self);
+
+static PyMethodDef t_relativedatetimeformatter_methods[] = {
+    DECLARE_METHOD(t_relativedatetimeformatter, format, METH_VARARGS),
+    DECLARE_METHOD(t_relativedatetimeformatter, combineDateAndTime, METH_VARARGS),
+    DECLARE_METHOD(t_relativedatetimeformatter, getNumberFormat, METH_NOARGS),
+    DECLARE_METHOD(t_relativedatetimeformatter, getCapitalizationContext, METH_NOARGS),
+    DECLARE_METHOD(t_relativedatetimeformatter, getFormatStyle, METH_NOARGS),
+    { NULL, NULL, 0, NULL }
+};
+
+DECLARE_TYPE(RelativeDateTimeFormatter, t_relativedatetimeformatter, UObject,
+             RelativeDateTimeFormatter, t_relativedatetimeformatter_init, NULL);
+
+#endif
+
 
 /* DateFormatSymbols */
 
@@ -1324,22 +1373,217 @@ DEFINE_RICHCMP(DateIntervalFormat, t_dateintervalformat);
 
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+
+/* RelativeDateTimeFormatter */
+
+static int t_relativedatetimeformatter_init(t_relativedatetimeformatter *self,
+                                            PyObject *args, PyObject *kwds)
+{
+    Locale *locale;
+    RelativeDateTimeFormatter *fmt;
+    NumberFormat *number_format;
+    UDateRelativeDateTimeFormatterStyle style;
+    UDisplayContext context;
+
+    switch (PyTuple_Size(args)) {
+      case 0:
+        INT_STATUS_CALL(fmt = new RelativeDateTimeFormatter(status));
+        self->object = fmt;
+        self->flags = T_OWNED;
+        break;
+      case 1:
+        if (!parseArgs(args, "P", TYPE_CLASSID(Locale), &locale))
+        {
+            INT_STATUS_CALL(fmt = new RelativeDateTimeFormatter(*locale, status));
+            self->object = fmt;
+            self->flags = T_OWNED;
+            break;
+        }
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+      case 2:
+        if (!parseArgs(args, "PP", TYPE_CLASSID(Locale),
+                       TYPE_CLASSID(NumberFormat), &locale, &number_format))
+        {
+            INT_STATUS_CALL(fmt = new RelativeDateTimeFormatter(
+                *locale, (NumberFormat *) number_format->clone(), status));
+            self->object = fmt;
+            self->flags = T_OWNED;
+            break;
+        }
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+      case 4:
+        if (!parseArgs(args, "PPii", TYPE_CLASSID(Locale),
+                       TYPE_CLASSID(NumberFormat), &locale, &number_format,
+                       &style, &context))
+        {
+            INT_STATUS_CALL(fmt = new RelativeDateTimeFormatter(
+                *locale, (NumberFormat *) number_format->clone(),
+                style, context, status));
+            self->object = fmt;
+            self->flags = T_OWNED;
+            break;
+        }
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+      default:
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+    }
+        
+    if (self->object)
+        return 0;
+
+    return -1;
+}
+
+static PyObject *t_relativedatetimeformatter_format(
+    t_relativedatetimeformatter *self, PyObject *args)
+{
+    UDateDirection direction = UDAT_DIRECTION_PLAIN;
+    UDateAbsoluteUnit abs_unit = UDAT_ABSOLUTE_NOW;
+    UDateRelativeUnit rel_unit = UDAT_RELATIVE_SECONDS;
+    UnicodeString *buffer;
+    double value;
+
+    switch (PyTuple_Size(args)) {
+      case 0: {
+        UnicodeString result;
+
+        STATUS_CALL(self->object->format(direction, abs_unit, result, status));
+        return PyUnicode_FromUnicodeString(&result);
+      }
+      case 1:
+        if (!parseArgs(args, "d", &value))
+        {
+            UnicodeString result;
+
+            STATUS_CALL(self->object->format(
+              value, UDAT_DIRECTION_NEXT, rel_unit, result, status));
+            return PyUnicode_FromUnicodeString(&result);
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &direction, &abs_unit))
+        {
+            UnicodeString result;
+
+            STATUS_CALL(self->object->format(
+                direction, abs_unit, result, status));
+            return PyUnicode_FromUnicodeString(&result);
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "iiU", &direction, &abs_unit, &buffer))
+        {
+            STATUS_CALL(self->object->format(
+                direction, abs_unit, *buffer, status));
+            Py_RETURN_ARG(args, 2);
+        }
+        if (!parseArgs(args, "dii", &value, &direction, &rel_unit))
+        {
+            UnicodeString result;
+
+            STATUS_CALL(self->object->format(
+                value, direction, rel_unit, result, status));
+            return PyUnicode_FromUnicodeString(&result);
+        }
+        break;
+      case 4:
+        if (!parseArgs(args, "diiU", &value, &direction, &rel_unit, &buffer))
+        {
+            STATUS_CALL(self->object->format(
+                value, direction, rel_unit, *buffer, status));
+            Py_RETURN_ARG(args, 3);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "format", args);
+}
+
+static PyObject *t_relativedatetimeformatter_combineDateAndTime(
+    t_relativedatetimeformatter *self, PyObject *args)
+{
+    UnicodeString *u, _u, *v, _v;
+    UnicodeString *buffer;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "SS", &u, &_u, &v, &_v))
+        {
+            UnicodeString result;
+
+            STATUS_CALL(self->object->combineDateAndTime(
+                *u, *v, result, status));
+            return PyUnicode_FromUnicodeString(&result);
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "SSU", &u, &_u, &v, &_v, &buffer))
+        {
+            STATUS_CALL(self->object->combineDateAndTime(
+                *u, *v, *buffer, status));
+            Py_RETURN_ARG(args, 2);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "combineDateAndTime", args);
+}
+
+static PyObject *t_relativedatetimeformatter_getNumberFormat(
+    t_relativedatetimeformatter *self)
+{
+    const NumberFormat &format = self->object->getNumberFormat();
+    return wrap_NumberFormat(const_cast<NumberFormat *>(&format), 0);
+}
+
+static PyObject *t_relativedatetimeformatter_getCapitalizationContext(
+    t_relativedatetimeformatter *self)
+{
+    return PyInt_FromLong(self->object->getCapitalizationContext());
+}
+
+static PyObject *t_relativedatetimeformatter_getFormatStyle(
+    t_relativedatetimeformatter *self)
+{
+    return PyInt_FromLong(self->object->getFormatStyle());
+}
+
+#endif
 
 void _init_dateformat(PyObject *m)
 {
-    DateFormatSymbolsType.tp_richcompare =
+    DateFormatSymbolsType_.tp_richcompare =
         (richcmpfunc) t_dateformatsymbols_richcmp;
-    SimpleDateFormatType.tp_str = (reprfunc) t_simpledateformat_str;
+    SimpleDateFormatType_.tp_str = (reprfunc) t_simpledateformat_str;
 #if U_ICU_VERSION_HEX >= 0x04000000
-    DateIntervalType.tp_str = (reprfunc) t_dateinterval_str;
-    DateIntervalType.tp_richcompare =
+    DateIntervalType_.tp_str = (reprfunc) t_dateinterval_str;
+    DateIntervalType_.tp_richcompare =
         (richcmpfunc) t_dateinterval_richcmp;
-    DateIntervalInfoType.tp_richcompare =
+    DateIntervalInfoType_.tp_richcompare =
         (richcmpfunc) t_dateintervalinfo_richcmp;
-    DateIntervalFormatType.tp_richcompare =
+    DateIntervalFormatType_.tp_richcompare =
         (richcmpfunc) t_dateintervalformat_richcmp;
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+    INSTALL_CONSTANTS_TYPE(UDateRelativeDateTimeFormatterStyle, m);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+    INSTALL_CONSTANTS_TYPE(UDisplayContext, m);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+    INSTALL_CONSTANTS_TYPE(UDateDirection, m);
+    INSTALL_CONSTANTS_TYPE(UDateAbsoluteUnit, m);
+    INSTALL_CONSTANTS_TYPE(UDateRelativeUnit, m);
+#endif
+
     REGISTER_TYPE(DateFormatSymbols, m);
     INSTALL_TYPE(DateFormat, m);
     REGISTER_TYPE(SimpleDateFormat, m);
@@ -1348,6 +1592,9 @@ void _init_dateformat(PyObject *m)
     REGISTER_TYPE(DateIntervalInfo, m);
     REGISTER_TYPE(DateIntervalFormat, m);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+    INSTALL_TYPE(RelativeDateTimeFormatter, m);
+#endif
 
     INSTALL_STATIC_INT(DateFormatSymbols, FORMAT);
     INSTALL_STATIC_INT(DateFormatSymbols, STANDALONE);
@@ -1424,4 +1671,55 @@ void _init_dateformat(PyObject *m)
     DateInterval_format =
         DateIntervalFormat::createInstance(UDAT_YEAR_ABBR_MONTH_DAY, status);
 #endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+    INSTALL_ENUM(UDateRelativeDateTimeFormatterStyle, "LONG", UDAT_STYLE_LONG);
+    INSTALL_ENUM(UDateRelativeDateTimeFormatterStyle, "SHORT", UDAT_STYLE_SHORT);
+    INSTALL_ENUM(UDateRelativeDateTimeFormatterStyle, "NARROW", UDAT_STYLE_NARROW);
+    INSTALL_ENUM(UDateRelativeDateTimeFormatterStyle, "COUNT", UDAT_STYLE_COUNT);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+    INSTALL_ENUM(UDisplayContext, "STANDARD_NAMES", UDISPCTX_STANDARD_NAMES);
+    INSTALL_ENUM(UDisplayContext, "DIALECT_NAMES", UDISPCTX_DIALECT_NAMES);
+    INSTALL_ENUM(UDisplayContext, "CAPITALIZATION_NONE", UDISPCTX_CAPITALIZATION_NONE);
+    INSTALL_ENUM(UDisplayContext, "CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE", UDISPCTX_CAPITALIZATION_FOR_MIDDLE_OF_SENTENCE);
+    INSTALL_ENUM(UDisplayContext, "CAPITALIZATION_FOR_BEGINNING_OF_SENTENCE", UDISPCTX_CAPITALIZATION_FOR_BEGINNING_OF_SENTENCE);
+    INSTALL_ENUM(UDisplayContext, "CAPITALIZATION_FOR_UI_LIST_OR_MENU", UDISPCTX_CAPITALIZATION_FOR_UI_LIST_OR_MENU);
+    INSTALL_ENUM(UDisplayContext, "CAPITALIZATION_FOR_STANDALONE", UDISPCTX_CAPITALIZATION_FOR_STANDALONE);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+    INSTALL_ENUM(UDisplayContext, "LENGTH_FULL", UDISPCTX_LENGTH_FULL);
+    INSTALL_ENUM(UDisplayContext, "LENGTH_SHORT", UDISPCTX_LENGTH_SHORT);
+#endif
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+    INSTALL_ENUM(UDateDirection, "LAST_2", UDAT_DIRECTION_LAST_2);
+    INSTALL_ENUM(UDateDirection, "LAST", UDAT_DIRECTION_LAST);
+    INSTALL_ENUM(UDateDirection, "THIS", UDAT_DIRECTION_THIS);
+    INSTALL_ENUM(UDateDirection, "NEXT", UDAT_DIRECTION_NEXT);
+    INSTALL_ENUM(UDateDirection, "NEXT_2", UDAT_DIRECTION_NEXT_2);
+    INSTALL_ENUM(UDateDirection, "PLAIN", UDAT_DIRECTION_PLAIN);
+
+    INSTALL_ENUM(UDateAbsoluteUnit, "SUNDAY", UDAT_ABSOLUTE_SUNDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "MONDAY", UDAT_ABSOLUTE_MONDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "TUESDAY", UDAT_ABSOLUTE_TUESDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "WEDNESDAY", UDAT_ABSOLUTE_WEDNESDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "THURSDAY", UDAT_ABSOLUTE_THURSDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "FRIDAY", UDAT_ABSOLUTE_FRIDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "SATURDAY", UDAT_ABSOLUTE_SATURDAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "DAY", UDAT_ABSOLUTE_DAY);
+    INSTALL_ENUM(UDateAbsoluteUnit, "WEEK", UDAT_ABSOLUTE_WEEK);
+    INSTALL_ENUM(UDateAbsoluteUnit, "MONTH", UDAT_ABSOLUTE_MONTH);
+    INSTALL_ENUM(UDateAbsoluteUnit, "YEAR", UDAT_ABSOLUTE_YEAR);
+    INSTALL_ENUM(UDateAbsoluteUnit, "NOW", UDAT_ABSOLUTE_NOW);
+
+    INSTALL_ENUM(UDateRelativeUnit, "SECONDS", UDAT_RELATIVE_SECONDS);
+    INSTALL_ENUM(UDateRelativeUnit, "MINUTES", UDAT_RELATIVE_MINUTES);
+    INSTALL_ENUM(UDateRelativeUnit, "HOURS", UDAT_RELATIVE_HOURS);
+    INSTALL_ENUM(UDateRelativeUnit, "DAYS", UDAT_RELATIVE_DAYS);
+    INSTALL_ENUM(UDateRelativeUnit, "WEEKS", UDAT_RELATIVE_WEEKS);
+    INSTALL_ENUM(UDateRelativeUnit, "MONTHS", UDAT_RELATIVE_MONTHS);
+    INSTALL_ENUM(UDateRelativeUnit, "YEARS", UDAT_RELATIVE_YEARS);
+#endif
 }
