@@ -118,6 +118,12 @@ class U_EXPORT PythonLEFontInstance : public LEFontInstance {
      * LEFontInstance API.
      */
 
+    virtual const void *getFontTable(LETag tableTag, size_t &length) const
+    {
+        length = -1;
+        return getFontTable(tableTag);
+    }
+
     virtual const void *getFontTable(LETag tag) const
     {
 #if PY_MAJOR_VERSION >= 3
@@ -558,11 +564,10 @@ void _init_layoutengine(PyObject *m)
     REGISTER_TYPE(LEFontInstance, m);
     REGISTER_TYPE(LayoutEngine, m);
 
-    INSTALL_STATIC_INT(LayoutEngine, kTypoFlagKern);
-    INSTALL_STATIC_INT(LayoutEngine, kTypoFlagLiga);
-
     INSTALL_ENUM(ScriptCode, "zyyy", zyyyScriptCode);
+#if U_ICU_VERSION_HEX >= 0x04040200
     INSTALL_ENUM(ScriptCode, "zinh", zinhScriptCode);
+#endif
     INSTALL_ENUM(ScriptCode, "qaai", qaaiScriptCode);
     INSTALL_ENUM(ScriptCode, "arab", arabScriptCode);
     INSTALL_ENUM(ScriptCode, "armn", armnScriptCode);
