@@ -38,6 +38,10 @@
     DECLARE_CONSTANTS_TYPE(UCurrencySpacing);
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+    DECLARE_CONSTANTS_TYPE(UNumberCompactStyle);
+#endif
+
 /* DecimalFormatSymbols */
 
 class t_decimalformatsymbols : public _wrapper {
@@ -101,6 +105,9 @@ static PyObject *t_numberformat_setMaximumFractionDigits(t_numberformat *self,
 static PyObject *t_numberformat_getMinimumFractionDigits(t_numberformat *self);
 static PyObject *t_numberformat_setMinimumFractionDigits(t_numberformat *self,
                                                         PyObject *arg);
+static PyObject *t_numberformat_isLenient(t_numberformat *self);
+static PyObject *t_numberformat_setLenient(t_numberformat *self,
+                                           PyObject *arg);
 static PyObject *t_numberformat_getCurrency(t_numberformat *self);
 static PyObject *t_numberformat_setCurrency(t_numberformat *self,
                                             PyObject *arg);
@@ -130,6 +137,8 @@ static PyMethodDef t_numberformat_methods[] = {
     DECLARE_METHOD(t_numberformat, setMaximumFractionDigits, METH_O),
     DECLARE_METHOD(t_numberformat, getMinimumFractionDigits, METH_NOARGS),
     DECLARE_METHOD(t_numberformat, setMinimumFractionDigits, METH_O),
+    DECLARE_METHOD(t_numberformat, isLenient, METH_NOARGS),
+    DECLARE_METHOD(t_numberformat, setLenient, METH_O),
     DECLARE_METHOD(t_numberformat, getCurrency, METH_NOARGS),
     DECLARE_METHOD(t_numberformat, setCurrency, METH_O),
     DECLARE_METHOD(t_numberformat, createInstance, METH_VARARGS | METH_CLASS),
@@ -319,6 +328,28 @@ static PyMethodDef t_decimalformat_methods[] = {
 DECLARE_TYPE(DecimalFormat, t_decimalformat, NumberFormat, DecimalFormat,
              t_decimalformat_init, NULL);
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+
+/* CompactDecimalFormat */
+
+class t_compactdecimalformat : public _wrapper {
+public:
+    CompactDecimalFormat *object;
+};
+
+static PyObject *t_compactdecimalformat_createInstance(PyTypeObject *type,
+                                                       PyObject *args);
+
+static PyMethodDef t_compactdecimalformat_methods[] = {
+    DECLARE_METHOD(t_compactdecimalformat, createInstance, METH_VARARGS | METH_CLASS),
+    { NULL, NULL, 0, NULL }
+};
+
+DECLARE_TYPE(CompactDecimalFormat, t_compactdecimalformat, DecimalFormat,
+             CompactDecimalFormat, abstract_init, NULL);
+
+#endif
+
 /* RuleBasedNumberFormat */
 
 class t_rulebasednumberformat : public _wrapper {
@@ -569,7 +600,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         }
         if (!parseArgs(args, "L", &l))
         {
-	  self->object->format((int64_t) l, _u);
+          self->object->format((int64_t) l, _u);
             return PyUnicode_FromUnicodeString(&_u);
         }
         break;
@@ -589,7 +620,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         if (!parseArgs(args, "LP", TYPE_CLASSID(FieldPosition),
                        &l, &fp))
         {
-	  self->object->format((int64_t) l, _u, *fp);
+          self->object->format((int64_t) l, _u, *fp);
             return PyUnicode_FromUnicodeString(&_u);
         }
         break;
@@ -609,7 +640,7 @@ static PyObject *t_numberformat_format(t_numberformat *self, PyObject *args)
         if (!parseArgs(args, "LUP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &fp))
         {
-	  self->object->format((int64_t) l, *u, *fp);
+          self->object->format((int64_t) l, *u, *fp);
             Py_RETURN_ARG(args, 1);
         }
         break;
@@ -876,6 +907,26 @@ static PyObject *t_numberformat_setMinimumFractionDigits(t_numberformat *self,
     return PyErr_SetArgsError((PyObject *) self, "setMinimumFractionDigits", arg);
 }
 
+static PyObject *t_numberformat_isLenient(t_numberformat *self)
+{
+    UBool n = self->object->isLenient();
+    Py_RETURN_BOOL(n);
+}
+
+static PyObject *t_numberformat_setLenient(t_numberformat *self,
+                                           PyObject *arg)
+{
+    int b;
+
+    if (!parseArg(arg, "b", &b))
+    {
+        self->object->setLenient(b);
+        Py_RETURN_NONE;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "setLenient", arg);
+}
+
 static PyObject *t_numberformat_getCurrency(t_numberformat *self)
 {
     UnicodeString u(self->object->getCurrency());
@@ -994,7 +1045,7 @@ static PyObject *t_numberformat_getAvailableLocales(PyTypeObject *type)
         Locale *locale = (Locale *) locales + i;
         PyObject *obj = wrap_Locale(locale, 0);
         PyDict_SetItemString(dict, locale->getName(), obj);
-	Py_DECREF(obj);
+        Py_DECREF(obj);
     }
 
     return dict;
@@ -1740,6 +1791,32 @@ static PyObject *t_decimalformat_str(t_decimalformat *self)
     return PyUnicode_FromUnicodeString(&u);
 }
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+
+/* CompactDecimalFormat */
+
+static PyObject *t_compactdecimalformat_createInstance(PyTypeObject *type,
+                                                       PyObject *args)
+{
+    CompactDecimalFormat *format;
+    Locale *locale;
+    UNumberCompactStyle style;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "Pi", TYPE_CLASSID(Locale), &locale, &style))
+        {
+            STATUS_CALL(format = CompactDecimalFormat::createInstance(
+                *locale, style, status));
+            return wrap_CompactDecimalFormat(format, T_OWNED);
+        }
+        break;
+    }
+            
+    return PyErr_SetArgsError(type, "createInstance", args);
+}
+
+#endif
 
 /* RuleBasedNumberFormat */
 
@@ -1937,7 +2014,7 @@ static PyObject *t_rulebasednumberformat_format(t_rulebasednumberformat *self,
         if (!parseArgs(args, "LSP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &_u, &fp))
         {
-	  STATUS_CALL(self->object->format((int64_t) l, *u, _v, *fp, status));
+          STATUS_CALL(self->object->format((int64_t) l, *u, _v, *fp, status));
             return PyUnicode_FromUnicodeString(&_v);
         }
       case 4:
@@ -1956,7 +2033,7 @@ static PyObject *t_rulebasednumberformat_format(t_rulebasednumberformat *self,
         if (!parseArgs(args, "LSUP", TYPE_CLASSID(FieldPosition),
                        &l, &u, &_u, &v, &fp))
         {
-	  STATUS_CALL(self->object->format((int64_t) l, *u, *v, *fp, status));
+          STATUS_CALL(self->object->format((int64_t) l, *u, *v, *fp, status));
             Py_RETURN_ARG(args, 2);
         }
         break;
@@ -2295,15 +2372,15 @@ static PyObject *t_choiceformat_str(t_choiceformat *self)
 
 void _init_numberformat(PyObject *m)
 {
-    DecimalFormatSymbolsType.tp_richcompare =
+    DecimalFormatSymbolsType_.tp_richcompare =
         (richcmpfunc) t_decimalformatsymbols_richcmp;
 #if U_ICU_VERSION_HEX >= 0x04020000
-    CurrencyPluralInfoType.tp_richcompare =
+    CurrencyPluralInfoType_.tp_richcompare =
         (richcmpfunc) t_currencypluralinfo_richcmp;
 #endif
-    DecimalFormatType.tp_str = (reprfunc) t_decimalformat_str;
-    RuleBasedNumberFormatType.tp_str = (reprfunc) t_rulebasednumberformat_str;
-    ChoiceFormatType.tp_str = (reprfunc) t_choiceformat_str;
+    DecimalFormatType_.tp_str = (reprfunc) t_decimalformat_str;
+    RuleBasedNumberFormatType_.tp_str = (reprfunc) t_rulebasednumberformat_str;
+    ChoiceFormatType_.tp_str = (reprfunc) t_choiceformat_str;
 
     REGISTER_TYPE(DecimalFormatSymbols, m);
     REGISTER_TYPE(NumberFormat, m);
@@ -2311,6 +2388,9 @@ void _init_numberformat(PyObject *m)
     REGISTER_TYPE(CurrencyPluralInfo, m);
 #endif
     REGISTER_TYPE(DecimalFormat, m);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+    REGISTER_TYPE(CompactDecimalFormat, m);
+#endif
     REGISTER_TYPE(RuleBasedNumberFormat, m);
     REGISTER_TYPE(ChoiceFormat, m);
 
@@ -2354,6 +2434,12 @@ void _init_numberformat(PyObject *m)
     INSTALL_ENUM(UCurrencySpacing, "INSERT", UNUM_CURRENCY_INSERT);
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(51, 0, 0)
+    INSTALL_CONSTANTS_TYPE(UNumberCompactStyle, m);
+    INSTALL_ENUM(UNumberCompactStyle, "SHORT", UNUM_SHORT);
+    INSTALL_ENUM(UNumberCompactStyle, "LONG", UNUM_LONG);
+#endif
+
     INSTALL_STATIC_INT(NumberFormat, kIntegerField);
     INSTALL_STATIC_INT(NumberFormat, kFractionField);
     INSTALL_STATIC_INT(NumberFormat, INTEGER_FIELD);
