@@ -38,12 +38,12 @@ DECLARE_CONSTANTS_TYPE(UScriptUsage);
 
 /* Script */
 
-struct UScript;
-typedef struct UScript UScript;
+struct UNone;
+typedef struct UNone UNone;
 
 class t_script : public _wrapper {
 public:
-    UScript *object;
+    UNone *object;
     UScriptCode code;
 };
 
@@ -86,7 +86,7 @@ static void t_script_dealloc(t_script *self)
     Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
-DECLARE_STRUCT(Script, t_script, UScript, t_script_init, t_script_dealloc);
+DECLARE_STRUCT(Script, t_script, UNone, t_script_init, t_script_dealloc);
 
 
 /* Script */
@@ -219,7 +219,7 @@ static PyObject *t_script_getScript(PyTypeObject *type, PyObject *arg)
   
         STATUS_CALL(code = uscript_getScript(u->char32At(0), &status));
 
-        return PyObject_CallFunction((PyObject *) type, "i", code);
+        return PyObject_CallFunction((PyObject *) type, (char *) "i", code);
     }
 
     return PyErr_SetArgsError((PyObject *) type, "getScript", arg);
